@@ -12,10 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo_config import cfg
 from oslo_policy import policy
 
-from monasca_log_api.policies import CHECK_AUTHORIZED_ROLES
+from monasca_log_api import policies
 
+CHECK_AUTHORIZED_ROLES = policies.roles_list_to_check_str(
+    cfg.CONF.roles_middleware.check_roles)
 
 rules = [
     policy.DocumentedRuleDefault(
